<?php
// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'EWP_STORE_URL', 'http://catchplugins.com' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the name of your product. This should match the download name in EDD exactly
define( 'EWP_ITEM_NAME', 'Catch Updater' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

if( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	// load our custom updater
	include( dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php' );
}


/************************************
* the code below is just a standard
* options page. Substitute with
* your own.
*************************************/

function catch_updater_license_page() {
	$license = get_option( 'catch_updater_license_key' );
	$status  = get_option( 'catch_updater_license_status' );
	?>
	<div class="wrap">
		<h2><?php esc_html_e( 'Plugin License Options', 'catch-updater' ); ?></h2>
		<form method="post" action="options.php">

			<?php settings_fields('catch_updater_license'); ?>
			<p class="description"><?php esc_html_e( 'Get Your license key for free at ', 'catch-updater' ); ?><a href="https://catchplugins.com/plugins/catch-updater/" target="blank" rel="nofollow">Catch Plugins</a></p>

			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row" valign="top">
							<?php esc_html_e( 'License Key', 'catch-updater' ); ?>
						</th>
						<td>
							<input id="catch_updater_license_key" name="catch_updater_license_key" type="text" class="regular-text" value="<?php echo esc_attr( $license ); ?>" />
							<label class="description" for="catch_updater_license_key"><?php esc_html_e( 'Enter your license key', 'catch-updater' ); ?></label>
						</td>
					</tr>
					<?php if ( false !== $license ) { ?>
						<tr valign="top">
							<th scope="row" valign="top">
								<?php esc_html_e( 'Activate License', 'catch-updater' ); ?>
							</th>
							<td>
								<?php if ( $status !== false && $status == 'valid' ) { ?>
									<span style="color:green;"><?php esc_html_e( 'Active', 'catch-updater' ); ?></span>
									<?php wp_nonce_field( 'catch_updater_nonce', 'catch_updater_nonce' ); ?>
									<input type="submit" class="button-secondary" name="edd_license_deactivate" value="<?php esc_html_e( 'Deactivate License', 'catch-updater' ); ?>"/>
								<?php } else {
									wp_nonce_field( 'catch_updater_nonce', 'catch_updater_nonce' ); ?>
									<input type="submit" class="button-secondary" name="edd_license_activate" value="<?php esc_html_e( 'Activate License', 'catch-updater'); ?>"/>
								<?php } ?>
							</td>
						</tr>
					<?php } ?>
				</tbody>
			</table>
			<?php submit_button(); ?>

		</form>
	<?php
}

function catch_updater_register_option() {
	// creates our settings in the options table
	register_setting('catch_updater_license', 'catch_updater_license_key', 'catch_updater_sanitize_license' );
}
add_action('admin_init', 'catch_updater_register_option');

function catch_updater_sanitize_license( $new ) {
	$old = get_option( 'catch_updater_license_key' );

	if( $old && $old != $new ) {
		delete_option( 'catch_updater_license_status' ); // new license has been entered, so must reactivate
	}

	return $new;
}

/************************************
* this illustrates how to activate
* a license key
*************************************/

function catch_updater_activate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['edd_license_activate'] ) ) {

		// run a quick security check
		if( ! check_admin_referer( 'catch_updater_nonce', 'catch_updater_nonce' ) ) {
			return; // get out if we didn't click the Activate button
		}

		// retrieve the license from the database
		$license = trim( get_option( 'catch_updater_license_key' ) );


		// data to send in our API request
		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => $license,
			'item_name'  => urlencode( EWP_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( EWP_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) ) {
			return false;
		}

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "valid" or "invalid"

		update_option( 'catch_updater_license_status', $license_data->license );
	}
}
add_action('admin_init', 'catch_updater_activate_license');

/***********************************************
* Illustrates how to deactivate a license key.
* This will descrease the site count
***********************************************/

function catch_updater_deactivate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['edd_license_deactivate'] ) ) {

		// run a quick security check
		if( ! check_admin_referer( 'catch_updater_nonce', 'catch_updater_nonce' ) ) {
			return; // get out if we didn't click the Activate button
		}

		// retrieve the license from the database
		$license = trim( get_option( 'catch_updater_license_key' ) );


		// data to send in our API request
		$api_params = array(
			'edd_action' => 'deactivate_license',
			'license'    => $license,
			'item_name'  => urlencode( EWP_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( EWP_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) ) {
			return false;
		}

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "deactivated" or "failed"
		if( $license_data->license == 'deactivated' ) {
			delete_option( 'catch_updater_license_status' );
		}

	}
}
add_action('admin_init', 'catch_updater_deactivate_license');

/************************************
* this illustrates how to check if
* a license key is still valid
* the updater does this for you,
* so this is only needed if you
* want to do something custom
*************************************/

function catch_updater_check_license() {

	global $wp_version;

	$license = trim( get_option( 'catch_updater_license_key' ) );

	$api_params = array(
		'edd_action' => 'check_license',
		'license'    => $license,
		'item_name'  => urlencode( EWP_ITEM_NAME ),
		'url'        => home_url()
	);

	// Call the custom API.
	$response = wp_remote_post( EWP_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

	if ( is_wp_error( $response ) ) {
		return false;
	}

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );

	if( $license_data->license == 'valid' ) {
		echo 'valid'; exit;
		// this license is still valid
	} else {
		echo 'invalid'; exit;
		// this license is no longer valid
	}
}
